# Generated by Django 3.2.25 on 2025-08-07 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orchestra', '0098_auto_20230405_2000'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staffingresponse',
            name='is_winner',
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name='todoqa',
            name='approved',
            field=models.BooleanField(blank=True, null=True),
        ),
    ]
